import { Request, Response } from 'express';
import { animals } from './index';
import { prismaMock } from '../singleton';

describe("Shelter API",  () => {
    test("should store invalid animal object", async () => {
        const status = jest.fn().mockReturnThis();
        const send = jest.fn().mockReturnThis()

        const response: Partial<Response> = { status, send }
        const request: Partial<Request> = {
            body: {
                "name": "Nix",
                "description": "Ahojte, volám sa Nix a som maličký, len pár týždňový kocúrik.",
                "age": 1,
                "sex": 1
            },
        }

        await animals.store(request as Request, response as Response);

        /**
        * @todo Write a test for creating an animal, just write your expections
        * @see https://jestjs.io/docs/expect
        */
        expect(status).toBeCalledWith(400);
        expect(send).toBeCalledWith({
            "data": ["addedAt is a required field"],
            "message": "addedAt is a required field",
            "status": "error"
        });
        expect(prismaMock.animal.create.mock.calls).toHaveLength(0);
    });

    test("should store valid animal object", async () => {
        const status = jest.fn().mockReturnThis();
        const send = jest.fn().mockReturnThis()

        const response: Partial<Response> = { status, send }
        const request: Partial<Request> = {
            body: {
                "name": "Nix",
                "description": "Ahojte, volám sa Nix a som maličký, len pár týždňový kocúrik.",
                "age": 1,
                "sex": 1,
                "addedAt": "2022-04-09T14:33:45.087Z"
            },
        }
        prismaMock.animal.create.mockResolvedValueOnce({
            "id": "3b78dc1e-45bd-4987-92f2-830f15f5ff73",
            "name": "Nix",
            "description": "Ahojte, volám sa Nix a som maličký, len pár týždňový kocúrik.",
            "age": 1,
            "sex": true,
            "type": "dog",
            "picture": "/images/animal.webp",
            "acceptedRequestId": null,
            "addedAt": new Date("2022-04-09T14:33:45.087Z"),
            "adoptedAt": null
        })
        await animals.store(request as Request, response as Response);

        /**
        * @todo Write a test for creating an animal, just write your expections
        * @see https://jestjs.io/docs/expect
        */
        expect(status).toBeCalledWith(201);
        expect(send).toBeCalledWith({
            "data":  {
              "acceptedRequestId": null,
              "addedAt": new Date("2022-04-09T14:33:45.087Z"),
              "adoptedAt": null,
              "age": 1,
              "description": "Ahojte, volám sa Nix a som maličký, len pár týždňový kocúrik.",
              "id": "3b78dc1e-45bd-4987-92f2-830f15f5ff73",
              "name": "Nix",
              "picture": "/images/animal.webp",
              "sex": true,
              "type": "dog",
            },
            "message": "Animal stored in system",
            "status": "success",
        });
        expect(prismaMock.animal.create.mock.calls).toHaveLength(1);
    });
});
