import { useForm } from 'react-hook-form';
import './createAnimal.css';
import axios from 'axios';
import Header from '../Header/Header';

enum Type {
  Cat = 'cat',
  Dog = 'dog',
}

enum Sex {
  Male,
  Female,
}

export const CreateAnimal = () => {
  const { register, handleSubmit, formState: { errors } } = useForm();

  const onSubmit = async (data: any) => {
    const headers = {
      'Content-Type': 'application/json'
    };
    const animalData = ({
      name: data.name,
      description: data.description,
      age: data.age,
      sex: data.sex === Sex.Female,
      type: data.type,
      picture: data.picture,
      addedAt: new Date()
    });

    await axios.post('http://localhost:4000/animals', animalData, { headers });
    alert('Animal successfully added');
  };

  return (
    <div>
      <Header/>
      <form className="form" onSubmit={handleSubmit(onSubmit)}>
        <label>Name:</label>
        <input
          className={`text-field ${errors.name && 'text-field--error'}`}
          {...register('name', { required: true })}
        />

        <label>Description:</label>
        <textarea
          className={`text-field ${errors.description && 'text-field--error'}`}
          {...register('description', { required: true })}
        />

        <label>Age:</label>
        <input
          className={`text-field ${errors.age && 'text-field--error'}`}
          {...register('age', { required: true })}
          type="number" step=".1"
        />

        <label>Type:</label>
        <select className="button" {...register('type', { required: true })}>
          <option value={Type.Dog}>Dog</option>
          <option value={Type.Cat}>Cat</option>
        </select>

        <label>Sex:</label>
        <select className="button" {...register('sex', { required: true })}>
          <option value={Sex.Male}>Male</option>
          <option value={Sex.Female}>Female</option>
        </select>

        <label>Picture:</label>
        <input
          className={`text-field ${errors.picture && 'text-field--error'}`}
          {...register('picture', { required: true })}
        />

        <input className="button" type="submit"/>
      </form>
    </div>
  );
};

export default CreateAnimal;
